#include <Servo.h> 

Servo servoLeft;              // Define left servo
Servo servoRight;             // Define right servo

volatile int pbLeft = LOW;    // Flag variable for left switch
volatile int pbRight = LOW;   // Flag variable for right switch
boolean started = false;      // True after robot first starts moving

void setup() {
  // Set pin modes for switches
  pinMode(2, INPUT);
  pinMode(3, INPUT);
  pinMode(4, OUTPUT);
  
  // Set internal pull up resistors for switches
  digitalWrite(2, HIGH);    // Right switch input
  digitalWrite(3, HIGH);    // Left switch input
  
  // Use pin 4 as a ground connection
  digitalWrite(4, LOW);
  
  servoLeft.attach(10);    // Set left servo to digital pin 10
  servoRight.attach(9);    // Set right servo to digital pin 9
  
  Serial.begin(9600);      // Start serial for debugging
    
  // Set up interrupts
  attachInterrupt(0, hitRight, FALLING);
  attachInterrupt(1, hitLeft, FALLING);
  
  started = true;         // Okay to allow robot to start moving
}

void loop() {
  
  if (pbLeft == HIGH) {           // If left bumper hit
    reverse();                    // Reverse for 1/2 second
    delay(500); 
    spinRight();                  // Spin for 1.5 seconds
    delay(1500);
    forward();                    // Go forward again
    pbLeft = LOW;                 // Reset flag and indicate "hit" in serial monitor
    Serial.println("pbLeft");
  }
  
  if (pbRight == HIGH) {          // If right bumper hit
    reverse();
    delay(500); 
    spinLeft();
    delay(1500);
    forward();
    pbRight = LOW;
    Serial.println("pbRight");  
  }

}
  
// Motion routines for forward, reverse, turns, and stop
void forward() {
  servoLeft.write(180);
  servoRight.write(0);
}
void reverse() {
  servoLeft.write(0);
  servoRight.write(180);
}
void spinLeft() {
  servoLeft.write(0);
  servoRight.write(0);
}
void spinRight() {
  servoLeft.write(180);
  servoRight.write(180);
}
void turnLeftFwd() {
  servoLeft.write(90);
  servoRight.write(0);
}
void turnRightFwd() {
  servoLeft.write(180);
  servoRight.write(90);
}
void turnLeftRev() {
  servoLeft.write(90);
  servoRight.write(180);
}
void turnRightRev() {
  servoLeft.write(0);
  servoRight.write(90);
}
void stopRobot() {
  servoLeft.write(90);
  servoRight.write(90);
}

// Interrupt handlers
void hitLeft() {
  if (started)              // If robot has started set flag to high
    pbLeft = HIGH;
}
void hitRight() {
  if (started)              // Same as left switch handler
    pbRight = HIGH;
}
