#include <Servo.h> 
#include "pitches.h"

Servo servoLeft;              // Define left servo
Servo servoRight;             // Define right servo

volatile int pbLeft = LOW;
volatile int pbRight = LOW;
boolean started = false;

void setup() {
  // Set pin modes for switches
  pinMode(2, INPUT);
  pinMode(3, INPUT);
  pinMode(4, OUTPUT);
  digitalWrite(2, HIGH);
  digitalWrite(3, HIGH);
  digitalWrite(4, LOW);     // Serves as ground connection
  
  pinMode(12, OUTPUT);      // Ground for speaker
  digitalWrite(12, LOW);
  
  servoLeft.attach(10);    // Set left servo to digital pin 10
  servoRight.attach(9);    // Set right servo to digital pin 9
  
  Serial.begin(9600);
    
  // Set up interrupts
  attachInterrupt(0, hitRight, FALLING);
  attachInterrupt(1, hitLeft, FALLING);
  
  started = true;
}

void loop() {
  
  if (pbLeft == HIGH) {           // If left bumper hit
    int tones[] = {NOTE_C4, NOTE_B3, NOTE_C4};
    int toneDurations[] = {4,4,4};
    reverse();
    makeTone(tones, toneDurations, sizeof(tones)/sizeof(int));
    delay(500); 
    spinRight();
    delay(1500);
    forward();
    pbLeft = LOW;
    Serial.println("pbLeft");
  }
  
  if (pbRight == HIGH) {          // If right bumper hit
    int tones[] = {NOTE_D6, NOTE_C3};
    int toneDurations[] = {4,4};
    reverse();
    makeTone(tones, toneDurations, sizeof(tones)/sizeof(int));
    delay(500); 
    spinLeft();
    delay(1500);
    forward();
    pbRight = LOW;
    Serial.println("pbRight");  
  }
}

void makeTone(int tones[], int toneDurations[], int length) {
  // Iterate notes of tune
  for (int thisNote = 0; thisNote < length; thisNote++) {

    //Calculate the note duration
    int toneDuration = 1000/toneDurations[thisNote];
    tone(13, tones[thisNote],toneDuration);

    //Add slight pause between notes
    int pauseBetweenNotes = toneDuration * 1.30;
    delay(toneDuration * 1.30);
    noTone(13);                      // Stop tone
  }
  return;
}

// Motion routines for forward, reverse, turns, and stop
void forward() {
  servoLeft.write(180);
  servoRight.write(0);
}
void reverse() {
  servoLeft.write(0);
  servoRight.write(180);
}
void spinLeft() {
  servoLeft.write(0);
  servoRight.write(0);
}
void spinRight() {
  servoLeft.write(180);
  servoRight.write(180);
}
void turnLeftFwd() {
  servoLeft.write(90);
  servoRight.write(0);
}
void turnRightFwd() {
  servoLeft.write(180);
  servoRight.write(90);
}
void turnLeftRev() {
  servoLeft.write(90);
  servoRight.write(180);
}
void turnRightRev() {
  servoLeft.write(0);
  servoRight.write(90);
}
void stopRobot() {
  servoLeft.write(90);
  servoRight.write(90);
}

// Interrupt handlers
void hitLeft() {
  if (started)
    pbLeft = HIGH;
}
void hitRight() {
  if (started) 
    pbRight = HIGH;
}
